@@ -59,13 +59,14 @@ Python library
 
 **subpackages**
 
-- config
-- misc
-- paths
-- plots
-- property
-- terminal
-- type_hints
+- :py:mod:`mypythontools.config`
+- :py:mod:`mypythontools.misc`
+- :py:mod:`mypythontools.paths`
+- :py:mod:`mypythontools.plots`
+- :py:mod:`mypythontools.property`
+- :py:mod:`mypythontools.system`
+- :py:mod:`mypythontools.terminal`
+- :py:mod:`mypythontools.types`
 
 Subpackages names are self describing and you can find documentation in subpackages docstrings.
 
@@ -136,7 +137,7 @@ from mypythontools import config, misc, paths, plots, property, system, types
 
 __all__ = ["config", "misc", "paths", "plots", "property", "system", "types"]
 
-__version__ = "1.0.9"
+__version__ = "1.0.10"
 
 __author__ = "Daniel Malachov"
 __license__ = "MIT"
